@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2007 Zuza Software Foundation
 #
@@ -22,6 +21,7 @@
 .. seealso:: http://en.wikipedia.org/wiki/Thai_language
 """
 
+
 from translate.lang import common
 
 
@@ -29,12 +29,12 @@ class th(common.Common):
     """This class represents Thai."""
 
     puncdict = {
-        u". ": u" ",
-        #u"; ": u" ", # Test interaction with XML entities
+        ". ": " ",
+        # "; ": " ", # Test interaction with XML entities
     }
 
     # No capitalisation. While we can't do sentence segmentation, sentencecount
     # is useless.
     ignoretests = {
-        'all': ["sentencecount", "simplecaps", "startcaps"],
+        "all": ["sentencecount", "simplecaps", "startcaps"],
     }
