@@ -60,7 +60,7 @@ def splitlines(text):
         text = text[3:]
     # Find first newline
     newline = b"\n"
-    msgid_pos = max(0, text.find(b"msgid "))
+    msgid_pos = max(0, text.find(b"\rmsgid ") + 1, text.find(b"\nmsgid ") + 1)
     for i, ch in enumerate(text[msgid_pos:]):
         # Iteration over bytes yields numbers in Python 3
         if ch == 10:
@@ -723,7 +723,7 @@ class pounit(pocommon.pounit):
 
         def add_prev_msgid_lines(lines, prefix, header, var):
             if var:
-                lines.append("{} {} {}\n".format(prefix, header, var[0]))
+                lines.append(f"{prefix} {header} {var[0]}\n")
                 lines.extend(f"{prefix} {line}\n" for line in var[1:])
 
         def add_prev_msgid_info(lines, prefix):
