@@ -19,10 +19,14 @@
 import re
 
 
-charset_re = re.compile('CHARACTER_SET[ ]+(?P<charset>.*)')
-header_item_or_end_re = re.compile('(((?P<key>[^ ]+)(?P<space>[ ]*:[ ]*)(?P<value>.*))|(?P<end_comment>[*]/))')
-header_item_re = re.compile('(?P<key>[^ ]+)(?P<space>[ ]*:[ ]*)(?P<value>.*)')
-string_entry_re = re.compile('(?P<start>rls_string[ ]+)(?P<id>[^ ]+)(?P<space>[ ]+)(?P<str>.*)')
+charset_re = re.compile("CHARACTER_SET[ ]+(?P<charset>.*)")
+header_item_or_end_re = re.compile(
+    "(((?P<key>[^ ]+)(?P<space>[ ]*:[ ]*)(?P<value>.*))|(?P<end_comment>[*]/))"
+)
+header_item_re = re.compile("(?P<key>[^ ]+)(?P<space>[ ]*:[ ]*)(?P<value>.*)")
+string_entry_re = re.compile(
+    "(?P<start>rls_string[ ]+)(?P<id>[^ ]+)(?P<space>[ ]+)(?P<str>.*)"
+)
 
 
 def identity(x):
@@ -30,11 +34,10 @@ def identity(x):
 
 
 class ParseState:
-
     def __init__(self, f, charset, read_hook=identity):
         self.f = f
         self.charset = charset
-        self.current_line = ''
+        self.current_line = ""
         self.read_hook = read_hook
         self.read_line()
 
@@ -54,13 +57,15 @@ def read_while(ps, f, test):
 
 
 def eat_whitespace(ps):
-    read_while(ps, identity, lambda line: line.strip() == '')
+    read_while(ps, identity, lambda line: line.strip() == "")
 
 
 def skip_no_translate(ps):
-    if ps.current_line.startswith('// DO NOT TRANSLATE'):
+    if ps.current_line.startswith("// DO NOT TRANSLATE"):
         ps.read_line()
-        read_while(ps, identity, lambda line: not line.startswith('// DO NOT TRANSLATE'))
+        read_while(
+            ps, identity, lambda line: not line.startswith("// DO NOT TRANSLATE")
+        )
         ps.read_line()
         eat_whitespace(ps)
 
@@ -69,5 +74,5 @@ def read_charset(lines):
     for line in lines:
         match = charset_re.match(line)
         if match is not None:
-            return match.groupdict()['charset']
-    return 'UTF-8'
+            return match.groupdict()["charset"]
+    return "UTF-8"
